@@ -1,6 +1,6 @@
 """Exception classes for operations involving quantities and units."""
 
-class IncompatibleUnitsException(Exception):
+class IncompatibleUnitsError(Exception):
     """Raised when an invalid operation is performed on 
         quantities with incompatible units."""
     pass
